import os

from ..pyfai_calib_average import CalibAverage


def test_pyfai_calib_average():
    datadir = os.path.abspath(os.path.dirname(__file__))
    data_path = os.path.join(
        datadir, "data", "pdfexample", "CeO2.h5" + "::entry_0000/measurement/data"
    )

    average_inputs2D = {"bliss_data_url": data_path}

    get_average2D = CalibAverage(inputs=average_inputs2D)
    get_average2D.execute()
    average2D = get_average2D.get_output_values()

    assert average2D["image"].ndim == 2



import os

from ..pyfai_calib_save import CalibSave


def test_pyfai_calib_save(tmpdir):
    datadir = os.path.abspath(os.path.dirname(__file__))
    spline_path = os.path.join(datadir, "data", "frelon.spline")
    detector_config = {
        "pixel1": 47e-6,
        "pixel2": 47e-6,
        "splineFile": spline_path,
        "max_shape": (2048, 2048),
    }
    geometry = {
        "dist": 0.2,
        "poni1": 0.046,
        "poni2": 0.05,
        "rot1": 0,
        "rot2": 0,
        "rot3": 0,
    }
    save_inputs = {
        "geometry": geometry,
        "calibrant": "CeO2",
        "detector": "Detector",
        "detector_config": detector_config,
        "output_path": [tmpdir],
        "energy": 43.5689,
    }
    save = CalibSave(inputs=save_inputs)
    save.execute()
    output_poni_paths = save.get_output_value("output_path")
    for output_poni_path in output_poni_paths:
        assert os.path.exists(output_poni_path)



import os
from datetime import datetime
from pyFAI.io import ponifile
from pyFAI.units import hc

from ewokscore import Task


class CalibSave(
    Task,
    input_names=[
        "geometry",
        "calibrant",
        "detector",
        "detector_config",
        "output_path",
        "energy",
    ],
    output_names=[
        "output_path",
    ],
):
    """Saves the geometry from calibration result in output_path. By default, the geometry file will be: {calibrant}_YYYYMMDD_hhmm.poni

    Inputs:
        - geometry: dictionnary, result of CalibrateSingle
        - calibrant: string with calibrant name used in CalibrateSingle
        - detector: string, default is detector
        - detector_config: dict with key splineFile
        - output_path: list of strings, where the poni will be saved
        - energy: float, in keV

    Outputs:
        - output_path: list of strings, path of the poni files saved
    """

    def run(self):
        now = datetime.now()
        dt_string = now.strftime("%Y%m%d_%H%M")
        poni_paths = []
        poni_pars = {
            "poni_version": 2,
            "detector": self.inputs.detector,
            "detector_config": self.inputs.detector_config,
            **self.inputs.geometry,
            "wavelength": (1e-10 * hc) / self.inputs.energy,
        }
        poni_obj = ponifile.PoniFile(poni_pars)
        for path in self.inputs.output_path:
            if not os.path.exists(path):
                os.makedirs(path)
            poni_path = os.path.join(path, f"{self.inputs.calibrant}_{dt_string}.poni")
            with open(poni_path, "w") as poniFile:
                poni_obj.write(poniFile)
            poni_paths.append(poni_path)
        self.outputs.output_path = poni_paths



import numpy
import os
import pytest

from ewoksid11.pdfgetx_config import PdfGetXConfig
from ewoksid11.pdfgetx_processor import PdfGetXProcessor


@pytest.fixture(scope="session")
def requires_diffpy():
    try:
        import diffpy  # noqa F401
    except ImportError:
        pytest.skip("requires 'diffpy'")


@pytest.fixture()
def setup_save_data(requires_diffpy):
    # Define file paths
    datadir = os.path.join(
        os.path.abspath(os.path.dirname(__file__)), "data", "pdfexample/"
    )
    config_file = os.path.join(datadir, "config.cfg")
    data_file = os.path.join(datadir, "CeO2.dat")

    # Configuration inputs
    config_inputs = {"filename": config_file}

    # Load data
    data = numpy.genfromtxt(data_file, delimiter="")

    # Create PdfGetXConfig instance and execute
    get_config = PdfGetXConfig(inputs=config_inputs)
    get_config.execute()
    config = get_config.get_output_values()

    # Extract data columns
    radial = data[:, 0]
    intensity = data[:, 1]

    # Processor inputs
    processor_inputs = {
        "radial": radial,
        "intensity": intensity,
        "info": {"unit": "q_A^-1"},
        "pdfgetx_options": config["pdfgetx_options"],
    }

    # Create PdfGetXProcessor instance and execute
    pdf_processor = PdfGetXProcessor(inputs=processor_inputs)
    pdf_processor.execute()
    processor_outputs = pdf_processor.get_output_values()
    return processor_outputs["result"]



import numpy as np
import hdf5plugin  # noqa F401
from ewokscore import Task
from silx.io.url import DataUrl
from silx.io import h5py_utils


class CalibAverage(
    Task,
    input_names=[
        "bliss_data_url",
    ],
    output_names=[
        "image",
    ],
):
    """Average a list of 2D images from bliss data url

    Inputs:
        - bliss_data_url: format like /data/visitor/maXXXX/idXX/20240101/sample/dataset/dataset.h5::1.1/measurement/detector
    Outputs:
        - image: 2D image averaged from list of 2D images
    """

    def run(self):
        bliss_data_url = DataUrl(self.inputs.bliss_data_url)
        with h5py_utils.open_item(
            bliss_data_url.file_path(), bliss_data_url.data_path()
        ) as NXIn:
            image = np.average(NXIn[:], axis=0)
        self.outputs.image = image



import h5py
import os.path
import json

from silx.io.dictdump import dicttonx
from ewoksxrpd.tasks.data_access import TaskWithDataAccess

from .constants import SIGNAL_TYPES


try:
    from diffpy import pdfgetx

    VERSION = pdfgetx.__version__
except ImportError:
    VERSION = None


class PdfGetXSaveNexus(
    TaskWithDataAccess,
    input_names=[
        "output_filename",
        "scan",
        "detector_name",
        "result",
        "pdfgetx_options",
    ],
    optional_input_names=["subscan"],
    output_names=["output_url"],
):
    """Saves the PDF result (iq, sq, fq, gr) in a NeXus file

    Inputs:
        - output_filename: h5file name where the data must be saved
        - scan: scan number
        - detector name: name of the detector
        - result: PDFGetter object with attributes defined by outputtype. Attributes are tuples with [0] X (radial) and [1] Y (intensity)
    Outputs:
        - output_url: URL of the NXprocess containing the saved data
    """

    def run(self):
        scan = self.inputs.scan
        subscan = self.get_input_value("subscan", 1)
        detector_name = self.inputs.detector_name
        output_filename = self.inputs.output_filename
        output_url = f"silx://{output_filename}?path=/{scan}.{subscan}"
        result = self.inputs.result
        info = pdfgetx_config_as_nxdict(self.inputs.pdfgetx_options)

        with self.open_h5item(output_url, mode="a", create=True) as data_parent:
            assert isinstance(data_parent, h5py.Group)
            nxprocess = data_parent.create_group(f"{detector_name}_PDF")
            nxprocess.attrs["NX_class"] = "NXprocess"

            dicttonx(
                info, data_parent.file, h5path=f"{nxprocess.name}", update_mode="modify"
            )
            for signal_type, signal_quantities in SIGNAL_TYPES.items():
                nxdata = nxprocess.create_group(signal_type)
                nxdata.attrs["NX_class"] = "NXdata"

                axis, signal = getattr(result, signal_type)
                signal_dset = nxdata.create_dataset(signal_type, data=signal)
                nxdata.attrs["signal"] = signal_type

                signal_dset.attrs["long_name"] = signal_quantities["y"].name
                signal_dset.attrs["units"] = signal_quantities["y"].unit

                axis_name, axis_unit = signal_quantities["x"]
                axis_dset = nxdata.create_dataset(axis_name, data=axis)
                axis_dset.attrs["unit"] = axis_unit

                nxdata.attrs["axes"] = axis_name

                nxprocess.attrs["default"] = signal_type

            nxprocess.parent.attrs["default"] = os.path.basename(nxprocess.name)
            self.outputs.output_url = f"silx://{output_filename}?path={nxprocess.name}"


def pdfgetx_config_as_nxdict(pdfgetx_config: dict) -> dict:
    """Convert pdfgetx config to a Nexus dictionary. Add keys and units when appropriate."""
    nxtree_dict = {
        "@NX_class": "NXprocess",
        "program": "pdfgetx",
        "version": VERSION,
    }
    nxtree_dict["configuration"] = {
        "@NX_class": "NXnote",
        "type": "application/json",
        "data": json.dumps(pdfgetx_config),
    }
    return nxtree_dict



import h5py
import numpy
import os
import json
from silx.io import utils as silx_io_utils


from ewoksid11.constants import SIGNAL_TYPES
from ewoksid11.constants import PDF_CONFIG_PARSED
from ewoksid11.pdfgetx_save_nexus import PdfGetXSaveNexus


def test_assert_save_nexus(setup_save_data, tmpdir):
    output_filename = os.path.join(tmpdir, "CeO2.h5")
    save_inputs = {
        "output_filename": output_filename,
        "scan": 2,
        "detector_name": "detector",
        "result": setup_save_data,
        "subscan": 2,
        "pdfgetx_options": dict(PDF_CONFIG_PARSED),
    }
    save = PdfGetXSaveNexus(inputs=save_inputs)
    save.execute()
    output_url = save.get_output_value("output_url")

    assert output_url == f"silx://{output_filename}?path=/2.2/detector_PDF"

    with silx_io_utils.open(output_url) as nxprocess:
        assert isinstance(nxprocess, h5py.Group)
        assert nxprocess.attrs["NX_class"] == "NXprocess"

        configuration = nxprocess["configuration"]
        assert configuration.attrs["NX_class"] == "NXnote"
        assert json.loads(configuration["data"][()]) == PDF_CONFIG_PARSED

        for signal_type in SIGNAL_TYPES:
            nxdata = nxprocess[signal_type]
            assert isinstance(nxdata, h5py.Group)
            assert nxdata.attrs["NX_class"] == "NXdata"

            expected_data = getattr(setup_save_data, signal_type)
            expected_axes = expected_data[0]
            axes_data = nxdata[nxdata.attrs["axes"]][()]
            numpy.testing.assert_allclose(expected_axes, axes_data)

            expected_signal = expected_data[1]
            signal_data = nxdata[nxdata.attrs["signal"]][()]
            numpy.testing.assert_allclose(expected_signal, signal_data)



import numpy as np
from ewokscore import Task

from .constants import CONFIG_ASCII_HEADER, DATA_ASCII_HEADER, SIGNAL_TYPES


class PdfGetXSaveAscii(
    Task,
    input_names=[
        "filename",
        "result",
    ],
    output_names=["saved", "filenames"],
):
    """Saves the PDF result (iq, sq, fq, gr) in separate ASCII files

    Inputs:
        - filename: h5file name that would have been used to save data from XrpdProcessor
        - result: PDFGetter object with attributes defined by outputtype. Attributes are tuples with [0] X (radial) and [1] Y (intensity)
    Outputs:
        - saved: True if saved
        - filename: list of saved filenames
    """

    def run(self):
        filename = self.inputs.filename
        self.outputs.filenames = []
        result = self.inputs.result
        for signal_type, signal_quantities in SIGNAL_TYPES.items():
            if not hasattr(result, signal_type):
                continue
            signal = getattr(result, signal_type)
            data = np.stack([signal[0], signal[1]], axis=1)
            config_header = self.header_config_writer(signal_type)
            data_header = DATA_ASCII_HEADER.format(
                f"{signal_quantities['x'].name} ({signal_quantities['x'].unit})",
                f"{signal_quantities['y'].name} ({signal_quantities['y'].unit})",
            )
            header = config_header + data_header
            np.savetxt(
                filename.replace("h5", signal_type),
                data,
                fmt="%10.7f",
                header=header,
                comments="",
            )
            self.outputs.filenames.append(filename.replace("h5", signal_type))
        self.outputs.saved = True

    def header_config_writer(self, signal_type: str):
        result = self.inputs.result
        config = result.config
        config.outputtypes = signal_type
        lines = CONFIG_ASCII_HEADER.split("\n")
        for i, line in enumerate(lines):
            parts = line.split("=")
            if len(parts) != 2:
                continue
            key = parts[0].strip()
            if hasattr(config, key):
                attr = getattr(config, key)
                lines[i] = (
                    f"{key} = {attr}".replace("[", "")
                    .replace("'", "")
                    .replace("]", "")
                    .replace("./", "")
                )
        updated_config_header = "\n".join(lines)
        return updated_config_header



import os
import numpy as np

from ewoksid11.constants import SIGNAL_TYPES
from ewoksid11.pdfgetx_save_ascii import PdfGetXSaveAscii


def assert_data_close(outputs, data_key, true_data, atol_multiplier=1e-5):
    atol = true_data[:, 1].max() * atol_multiplier
    computed_data = getattr(outputs, data_key)
    np.testing.assert_allclose(computed_data[0], true_data[:, 0], rtol=1e-6)
    np.testing.assert_allclose(computed_data[1], true_data[:, 1], atol=atol)


def test_assert_save_ascii(setup_save_data, tmpdir):
    save_result_input = setup_save_data
    dsetname = "CeO2.h5"
    save_inputs = {
        "filename": os.path.join(tmpdir, dsetname),
        "result": save_result_input,
    }
    save = PdfGetXSaveAscii(inputs=save_inputs)
    save.execute()

    for signal_type in SIGNAL_TYPES:
        with open(save_inputs["filename"].replace("h5", signal_type), "r") as f_in:
            cfg_lines = f_in.readlines()[10:27]  # Skip header to calculation setup
        for i, line in enumerate(cfg_lines):
            cfg_parts = line.split("=")
            if len(cfg_parts) == 2:
                key = cfg_parts[0].strip()
                value = cfg_parts[1].strip()
                expected_value = getattr(save_result_input.config, key)
                if isinstance(expected_value, str) or isinstance(expected_value, float):
                    assert value == str(expected_value)
                if isinstance(expected_value, list):
                    assert value == str(expected_value[0])
        data = np.genfromtxt(
            save_inputs["filename"].replace("h5", signal_type), skip_header=27
        )
        assert_data_close(save_result_input, signal_type, data)



import numpy as np
import json
from ewokscore import Task
from silx.io.url import DataUrl
from silx.io import h5py_utils


class PdfGetXAverage(
    Task,
    input_names=[
        "nxdata_url",
    ],
    output_names=[
        "radial",
        "intensity",
        "info",
    ],
):
    """Average a list of 1D XRPD patterns from provided output of IntegrateBlissScan

    Inputs:
        - nxdata_url: .h5 path with NXData url
    Outputs:
        - radial: 1D array
        - intensity: 1D array
        - info: dict with radial_units and wavelength
    """

    def run(self):
        nxdata_url = DataUrl(self.inputs.nxdata_url)
        with h5py_utils.open_item(
            nxdata_url.file_path(), nxdata_url.data_path()
        ) as NXIn:
            intensity = NXIn[NXIn.attrs["signal"]][:]
            radial = NXIn[NXIn.attrs["axes"][1]][:]
            info = json.loads(NXIn.parent["configuration/data"][()])
        if intensity.ndim == 1:
            pass
        elif intensity.ndim == 2:
            intensity = np.average(intensity, axis=0)
        else:
            raise ValueError("intensity dimension %s not supported" % intensity.ndim)
        self.outputs.intensity = intensity
        self.outputs.radial = radial
        self.outputs.info = info



from ewokscore import Task

try:
    from diffpy import pdfgetx
except ImportError:
    pdfgetx = None


class PdfGetXConfig(
    Task,
    optional_input_names=["filename", "pdfgetx_options_dict"],
    output_names=["pdfgetx_options"],
):
    """Parse pdfgetx config parameters"""

    def run(self):
        if pdfgetx is None:
            raise RuntimeError("requires 'diffpy'")
        pdfgetx_options = self.merged_pdfgetx_config()
        self.outputs.pdfgetx_options = pdfgetx_options

    def merged_pdfgetx_config(self):
        """Merge pdfgetx options in this order of priority:

        - filename (lowest priority)
        - pdfgetx_options (highest priority)
        """
        if self.inputs.filename:
            options = pdfgetx.loadPDFConfig(self.inputs.filename)
        else:
            options = pdfgetx.PDFConfig()
        pdfgetx_options = self.get_input_value("pdfgetx_options_dict", dict())
        for key, value in pdfgetx_options.items():
            setattr(options, key, value)
        return options



import os
import pytest

from ..pdfgetx_config import PdfGetXConfig
from ewoksid11.constants import PDF_CONFIG_PARSED


@pytest.fixture()
def pdfgetx_config_file():
    datadir = os.path.abspath(os.path.dirname(__file__))
    filename = os.path.join(datadir, "data/pdfexample/config.cfg")
    return filename


def test_pdfgetx_config(requires_diffpy, pdfgetx_config_file):
    """Test PDFgetX parameters from file"""
    inputs = {"filename": pdfgetx_config_file}
    task = PdfGetXConfig(inputs=inputs)
    task.execute()
    actual_values = task.get_output_value("pdfgetx_options")
    expected_values = dict(PDF_CONFIG_PARSED)
    _assert_pdfgetx_parameter(actual_values, expected_values)


def test_pdfgetx_config_overwrite(requires_diffpy, pdfgetx_config_file):
    """Test PDFgetX parameters from file with overwriting"""
    inputs = {"filename": pdfgetx_config_file, "pdfgetx_options_dict": {"rmin": 1}}
    task = PdfGetXConfig(inputs=inputs)
    task.execute()
    actual_values = task.get_output_value("pdfgetx_options")
    expected_values = dict(PDF_CONFIG_PARSED)
    expected_values["rmin"] = 1
    _assert_pdfgetx_parameter(actual_values, expected_values)


def _assert_pdfgetx_parameter(actual_values, expected_values):
    for attribute, expected_value in expected_values.items():
        # Check if the attribute exists in the object
        assert hasattr(actual_values, attribute), f"Attribute '{attribute}' is missing."
        actual_value = getattr(actual_values, attribute)

        if (
            attribute == "bgscale"
        ):  # For some reasons bgscale is not a single value but parsed as a list...
            assert float(str(actual_value[0])) == float(
                expected_value
            ), f"Attribute '{attribute}' has an unexpected value: {actual_value} (expected: {expected_value})."
            continue

        if (
            attribute == "backgroundfile"
        ):  # For some reasons backgroundfile is not a single value but parsed as a list...
            assert (
                str(actual_value[0]) == expected_value
            ), f"Attribute '{attribute}' has an unexpected value: {actual_value} (expected: {expected_value})."
            continue

        if attribute == "outputtype":  # Need an extra step to convert string to list
            assert actual_value == expected_value.split(
                ", "
            ), f"Attribute '{attribute}' has an unexpected value: {actual_value} (expected: {expected_value})."
            continue

        if attribute in [
            "force",
            "interact",
        ]:  # Keys that can be yes/no are parsed as True/False #TODO Handle the case 'once' for force
            if expected_value.lower() in ["true", "yes", "on", "1"]:
                expected_value = True
            elif expected_value.lower() in ["false", "no", "off", "0"]:
                expected_value = False
            assert (
                actual_value == expected_value
            ), f"Attribute '{attribute}' has an unexpected value: {actual_value} (expected: {expected_value})."
            continue

        if (
            expected_value == "" or expected_value == "none"
        ):  # Do not consider empty keys
            continue
        elif (
            str(expected_value).replace(".", "").isnumeric()
        ):  # Check if the keys are numeric needs extra str to float step
            assert actual_value == float(
                expected_value
            ), f"Attribute '{attribute}' has an unexpected value: {float(actual_value)} (expected: {float(expected_value)})."
        else:
            assert (
                actual_value == expected_value
            ), f"Attribute '{attribute}' has an unexpected value: {actual_value} (expected: {expected_value})."



import os

from ..pdfgetx_average import PdfGetXAverage


def test_pdfgetx_average():
    datadir = os.path.abspath(os.path.dirname(__file__))
    data_path = os.path.join(
        datadir,
        "data",
        "pdfexample",
        "CeO2_processed.h5::1.1/frelon6_integrate/integrated",
    )

    average_inputs2D = {"nxdata_url": data_path}

    get_average2D = PdfGetXAverage(inputs=average_inputs2D)
    get_average2D.execute()
    average2D = get_average2D.get_output_values()

    assert average2D["intensity"].ndim == 1



import os
import pytest
import numpy as np

from ..pdfgetx_config import PdfGetXConfig
from ..pdfgetx_processor import PdfGetXProcessor


@pytest.fixture()
def setup_data(requires_diffpy):
    # Define file paths
    datadir = os.path.join(
        os.path.abspath(os.path.dirname(__file__)), "data", "pdfexample"
    )
    config_file = os.path.join(datadir, "config.cfg")
    data_file = os.path.join(datadir, "CeO2.dat")

    # Configuration inputs
    config_inputs = {"filename": config_file}

    # Load data
    data = np.genfromtxt(data_file, delimiter="")

    # Create PdfGetXConfig instance and execute
    get_config = PdfGetXConfig(inputs=config_inputs)
    get_config.execute()
    config = get_config.get_output_values()

    # Extract data columns
    radial = data[:, 0]
    intensity = data[:, 1]

    # Processor inputs
    processor_inputs = {
        "radial": radial,
        "intensity": intensity,
        "info": {"unit": "q_A^-1"},
        "pdfgetx_options": config["pdfgetx_options"],
    }

    # Create PdfGetXProcessor instance and execute
    pdf_processor = PdfGetXProcessor(inputs=processor_inputs)
    pdf_processor.execute()
    outputs = pdf_processor.get_output_values()

    # Load true data
    true_iq = np.genfromtxt(
        os.path.join(datadir, "CeO2.iq"), delimiter="", skip_header=27
    )
    true_sq = np.genfromtxt(
        os.path.join(datadir, "CeO2.sq"), delimiter="", skip_header=27
    )
    true_fq = np.genfromtxt(
        os.path.join(datadir, "CeO2.fq"), delimiter="", skip_header=27
    )
    true_gr = np.genfromtxt(
        os.path.join(datadir, "CeO2.gr"), delimiter="", skip_header=27
    )

    return outputs, true_iq, true_sq, true_fq, true_gr


def test_data(setup_data):
    outputs, true_iq, true_sq, true_fq, true_gr = setup_data

    # Define a function for testing data
    def assert_data_close(data_key, true_data, atol_multiplier=1e-5):
        atol = true_data[:, 1].max() * atol_multiplier
        computed_data = getattr(outputs["result"], data_key)
        np.testing.assert_allclose(computed_data[0], true_data[:, 0], rtol=1e-6)
        np.testing.assert_allclose(computed_data[1], true_data[:, 1], atol=atol)

    # Testing iq, sq, fq, and gr
    assert_data_close("iq", true_iq)
    assert_data_close("sq", true_sq)
    assert_data_close("fq", true_fq)
    assert_data_close("gr", true_gr)



from ewokscore import Task

try:
    from diffpy import pdfgetx
except ImportError:
    pdfgetx = None


class PdfGetXProcessor(
    Task,
    input_names=[
        "radial",
        "intensity",
        "info",
        "pdfgetx_options",
    ],
    output_names=[
        "result",
        "pdfgetx_options",
    ],
):
    """Extracts the PDF signal from provided intensities and radial

    Inputs:
        - radial: 1D array
        - intensity: 1D array
        - info: dict with unit and wavelength
        - pdfgetx_options: PDFConfig object
    Outputs:
        - result: PDFGetter object with attributes defined by outputtype. Attributes are tuples with [0] X (radial) and [1] Y (intensity)
        - pdfgetx_options: PDFConfig object
    """

    def run(self):
        cfg = self.inputs.pdfgetx_options
        if pdfgetx is None:
            raise ImportError("diffpy couldn't be imported")
        worker = pdfgetx.PDFGetter(cfg)
        worker(self.inputs.radial, self.inputs.intensity)
        self.outputs.result = worker
        self.outputs.pdfgetx_options = cfg



from __future__ import annotations
from collections import namedtuple

PhysicalQuantity = namedtuple("PhysicalQuantity", ("name", "unit"))

CONFIG_ASCII_HEADER = """[DEFAULT]

version = diffpy.pdfgetx-2.2.1

# input and output specifications
dataformat = QA
inputfile = CeO2.dat
backgroundfile = background.xy
outputtype = fq

# PDF calculation setup
mode = xray
composition = CeO2
bgscale = 0
rpoly = 0
qmaxinst = 0
qmin = 0
qmax = 0
rmin = 0
rmax = 0
rstep = 0

# End of config --------------------------------------------------------------
"""

DATA_ASCII_HEADER = """
#### start data
#S 1
#L {} {}"""


SIGNAL_TYPES: dict[str, dict[str, PhysicalQuantity]] = {
    "iq": {
        "x": PhysicalQuantity("Q", "Å$^{-1}$"),
        "y": PhysicalQuantity("intensity", "a.u."),
    },
    "sq": {"x": PhysicalQuantity("Q", "Å$^{-1}$"), "y": PhysicalQuantity("S", "a.u.")},
    "fq": {
        "x": PhysicalQuantity("Q", "Å$^{-1}$"),
        "y": PhysicalQuantity("F", "Å$^{-1}$"),
    },
    "gr": {"x": PhysicalQuantity("r", "Å"), "y": PhysicalQuantity("G", "Å$^{-2}$")},
}

PDF_CONFIG_PARSED = {
    "dataformat": "QA",
    "backgroundfile": "./background.xy",
    "datapath": "",
    "bgscale": "1",
    "composition": "CeO2",
    "force": "yes",
    "interact": "yes",
    "mode": "xray",
    "output": "@r.@o",
    "outputtype": "iq, sq, fq, gr",
    "plot": "none",
    "qmax": "25",
    "qmaxinst": "25",
    "qmin": "1.10",
    "rmax": "30.0",
    "rmin": "0.0",
    "rpoly": "1.8",
    "rstep": "0.01",
    "wavelength": "0.1408839",
}
